;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "flymake-phpstan" "20250930.1139"
  "Flymake backend for PHP using PHPStan."
  '((emacs   "26.1")
    (phpstan "0.9.0"))
  :url "https://github.com/emacs-php/phpstan.el"
  :commit "07ef7531f2ec73b90a965ac865cca8c96086f9de"
  :revdesc "07ef7531f2ec"
  :keywords '("tools" "php")
  :authors '(("USAMI Kenta" . "tadsan@zonu.me"))
  :maintainers '(("USAMI Kenta" . "tadsan@zonu.me")))
